NLSL: assgnc.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
assgnc.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | assgnc (line)
subroutine | getss (line, ixss)

## Function/Subroutine Documentation

subroutine assgnc | ( | character*80 | line | ) |

Definition at line 17 of file assgnc.f90.

Here is the call graph for this function:

Here is the caller graph for this function:

subroutine getss | ( | character*80 | line,
|  | integer, dimension(2) | ixss
| ) |  |

Definition at line 126 of file assgnc.f90.

Here is the call graph for this function:

Here is the caller graph for this function: